@@ -125,7 +125,7 @@ class SubfunctionsTEST(unittest.TestCase):
                 seg_list.append(data_patches[i][1])
             seg = np.stack(seg_list, axis=0)
             self.assertEqual(seg.shape, (27,4,4,4,3))
-            pred = pp.postprocessing(index, seg)
+            pred = pp.postprocessing(sample, seg)
             self.assertEqual(pred.shape, (16,16,16))
         self.tmp_dir.cleanup()
 
@@ -197,7 +197,7 @@ class SubfunctionsTEST(unittest.TestCase):
             self.assertIsNotNone(seg)
             self.assertEqual(img.shape, (1,8,8,8,1))
             self.assertEqual(seg.shape, (1,8,8,8,3))
-        self.tmp_dir.cleanup()
+        #self.tmp_dir.cleanup()
 
     #-------------------------------------------------#
     #                    Resizing                     #
@@ -238,7 +238,7 @@ class SubfunctionsTEST(unittest.TestCase):
             # Transform segmentation data to simulate prediction data
             sample_pred.pred_data = np.squeeze(sample_train.seg_data, axis=-1)
             # Run postprocessing of the subfunction
-            pred = sf.postprocessing(sample_pred.pred_data)
+            pred = sf.postprocessing(sample_pred, sample_pred.pred_data)
             # Check for correctness
             if dim == "2D" : old_shape = (16,16)
             else : old_shape = (16,16,16)
@@ -262,7 +262,7 @@ class SubfunctionsTEST(unittest.TestCase):
                 sample = deepcopy(getattr(self, varname))
                 if dim == "2D" : old_spacing = (1.8, 3.0)
                 else : old_spacing = (1.8, 3.0, 3.0)
-                sample.details = {"spacing":np.array(old_spacing)}
+                sample.extended = {"spacing":np.array(old_spacing)}
                 # Run preprocessing of the subfunction
                 sf.preprocessing(sample, training=train)
                 # Check for correctness
@@ -288,15 +288,15 @@ class SubfunctionsTEST(unittest.TestCase):
             sample_train = deepcopy(getattr(self, "sample" + dim + "seg"))
             if dim == "2D" : old_spacing = (1.8, 3.0)
             else : old_spacing = (1.8, 3.0, 3.0)
-            sample_pred.details = {"spacing":np.array(old_spacing)}
-            sample_train.details = {"spacing":np.array(old_spacing)}
+            sample_pred.extended = {"spacing":np.array(old_spacing)}
+            sample_train.extended = {"spacing":np.array(old_spacing)}
             # Run preprocessing of the subfunction
             sf.preprocessing(sample_train, training=True)
             sf.preprocessing(sample_pred, training=False)
             # Transform segmentation data to simulate prediction data
             sample_pred.pred_data = np.squeeze(sample_train.seg_data, axis=-1)
             # Run postprocessing of the subfunction
-            pred = sf.postprocessing(sample_pred.pred_data)
+            pred = sf.postprocessing(sample_pred, sample_pred.pred_data)
             # Check for correctness
             if dim == "2D" : old_shape = (16,16)
             else : old_shape = (16,16,16)
@@ -316,8 +316,8 @@ class SubfunctionsTEST(unittest.TestCase):
             sample_train = deepcopy(getattr(self, "sample" + dim + "seg"))
             if dim == "2D" : old_spacing = (1.8, 3.0)
             else : old_spacing = (1.8, 3.0, 3.0)
-            sample_pred.details = {"spacing":np.array(old_spacing)}
-            sample_train.details = {"spacing":np.array(old_spacing)}
+            sample_pred.extended = {"spacing":np.array(old_spacing)}
+            sample_train.extended = {"spacing":np.array(old_spacing)}
             # Run preprocessing of the subfunction
             sf.preprocessing(sample_train, training=True)
             sf.preprocessing(sample_pred, training=False)
@@ -327,7 +327,7 @@ class SubfunctionsTEST(unittest.TestCase):
             else:
                 sample_pred.pred_data = np.random.rand(16, 16, 16, 3) * 3
             # Run postprocessing of the subfunction
-            pred = sf.postprocessing(sample_pred.pred_data)
+            pred = sf.postprocessing(sample_pred, sample_pred.pred_data)
             # Check for correctness
             if dim == "2D" : old_shape = (16,16,3)
             else : old_shape = (16,16,16,3)
@@ -374,7 +374,7 @@ class SubfunctionsTEST(unittest.TestCase):
             # Transform segmentation data to simulate prediction data
             sample_pred.pred_data = np.squeeze(sample_train.seg_data, axis=-1)
             # Run postprocessing of the subfunction
-            pred = sf.postprocessing(sample_pred.pred_data)
+            pred = sf.postprocessing(sample_pred, sample_pred.pred_data)
             # Check for correctness
             if dim == "2D" : old_shape = (16,16)
             else : old_shape = (16,16,16)
@@ -416,7 +416,7 @@ class SubfunctionsTEST(unittest.TestCase):
             # Transform segmentation data to simulate prediction data
             sample_pred.pred_data = np.squeeze(sample_train.seg_data, axis=-1)
             # Run postprocessing of the subfunction
-            pred = sf.postprocessing(sample_pred.pred_data)
+            pred = sf.postprocessing(sample_pred, sample_pred.pred_data)
             # Check for correctness
             self.assertTrue(np.array_equal(pred, sample_pred.pred_data))
 
@@ -467,7 +467,7 @@ class SubfunctionsTEST(unittest.TestCase):
                 # Transform segmentation data to simulate prediction data
                 sample_pred.pred_data = np.squeeze(sample_train.seg_data, axis=-1)
                 # Run postprocessing of the subfunction
-                pred = sf.postprocessing(sample_pred.pred_data)
+                pred = sf.postprocessing(sample_pred, sample_pred.pred_data)
                 # Check for correctness
                 self.assertTrue(np.array_equal(pred, sample_pred.pred_data))
 
@@ -512,6 +512,6 @@ class SubfunctionsTEST(unittest.TestCase):
             # Transform segmentation data to simulate prediction data
             sample_pred.pred_data = np.squeeze(sample_train.seg_data, axis=-1)
             # Run postprocessing of the subfunction
-            pred = sf.postprocessing(sample_pred.pred_data)
+            pred = sf.postprocessing(sample_pred, sample_pred.pred_data)
             # Check for correctness
             self.assertTrue(np.array_equal(pred, sample_pred.pred_data))
